@@ -8,20 +8,6 @@
 #' @useDynLib  dggridR
 
 
-#' @name dg_exe_path
-#' 
-#' @title Get path to dggrid executable
-#'
-#' @description
-#'        Returns a path to the dggrid executable. Used for running stuff.
-#'
-#' @return A string representing the path to the dggrid executable.
-#'
-dg_exe_path <- function(){
-  exe_name <- switch(Sys.info()[['sysname']], Windows='dggrid.exe', 'dggrid')
-  file.path(find.package('dggridR'), "bin", exe_name)
-}
-
 #' @name dg_env
 #' 
 #' @title Control global aspects of the dggridR package
@@ -108,11 +94,12 @@ dg_shpfname_south_africa <- function(){
 #'                  functions
 #'
 #' @examples 
+#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #'
 #' dggs <- dgconstruct(area=5,metric=FALSE)
-#'
+#' }
 #' @export 
 dgconstruct <- function(
   projection   = 'ISEA',
@@ -183,10 +170,11 @@ dgconstruct <- function(
 #'             functions
 #'
 #' @examples 
+#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' dggs <- dgsetres(dggs,10)
-#'
+#' }
 #' @export 
 dgsetres <- function(dggs,res){
   dggs[['res']] = res
@@ -208,10 +196,11 @@ dgsetres <- function(dggs,res){
 #' @return     The function has no return value. A stop signal is raised if the
 #'             object is misspecified
 #' @examples
+#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' dgverify(dggs)
-#'
+#' }
 #' @export
 dgverify <- function(dggs){
   #See page 21 of documentation for further bounds
@@ -259,18 +248,19 @@ dgverify <- function(dggs){
 #'             in the discrete grid.
 #'
 #' @examples 
+#' \dontrun{
 #' library(dggridR)
 #' data(dgquakes)
 #'
 #' #Construct a grid with cells about ~1000 miles wide
 #' dggs          <- dgconstruct(spacing=1000,metric=FALSE) 
 #' dgquakes$cell <- dgtransform(dggs,dgquakes$lat,dgquakes$lon)
-#'
+#' }
 #' @export 
 dgtransform <- function(dggs, lat, lon){ #TODO: Make sure we're not modifying the original dggs
   dgverify(dggs)
 
-  warning("The 'dgtransform' function has been deprecated. Please use 'dgGEO_to_SEQNUM' instead!")
+  warning("The 'dgtransform(dggs,lat,lon)' function has been deprecated. Please use 'dgGEO_to_SEQNUM(dggs,lon,lat)' instead! NOTE THE ARGUMENT ORDER!")
 
   dgGEO_to_SEQNUM(dggs, lon, lat)$seqnum
 }
@@ -290,10 +280,11 @@ dgtransform <- function(dggs, lat, lon){ #TODO: Make sure we're not modifying th
 #' @return No return. All info is printed to the screen.
 #'
 #' @examples 
+#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' dginfo(dggs)
-#'
+#' }
 #' @export 
 dginfo <- function(dggs){
   dgverify(dggs)
@@ -326,10 +317,11 @@ dginfo <- function(dggs){
 #'             scale of the cells. All values are in kilometres.
 #'
 #' @examples 
+#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' dggetres(dggs)
-#'
+#' }
 #' @export 
 dggetres <- function(dggs){
   dgverify(dggs)
@@ -363,6 +355,7 @@ dggetres <- function(dggs){
 #' @return     The maximum cell id.
 #'
 #' @examples 
+#' \dontrun{
 #' #Choose a set of cells randomly distributed over the Earth
 #' library(dggridR)
 #' dggs    <- dgconstruct(spacing=1000, metric=FALSE, resround='down')
@@ -370,7 +363,7 @@ dggetres <- function(dggs){
 #' maxcell <- dgmaxcell(dggs)                     #Get maximum cell id
 #' cells   <- sample(1:maxcell, N, replace=FALSE) #Choose random cells
 #' grid    <- dgcellstogrid(dggs,cells,frame=TRUE,wrapcells=TRUE) #Get grid
-#'
+#' }
 #' @export 
 dgmaxcell <- function(dggs,res=NA){
   dgverify(dggs)
@@ -475,11 +468,12 @@ dg_closest_res <- function(dggs,col,val,round='nearest',show_info=TRUE,metric=TR
 #' @return A number representing the grid resolution
 #'
 #' @examples 
+#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' res  <- dg_closest_res_to_area(dggs,1)
 #' dggs <- dgsetres(dggs,res)
-#'
+#' }
 #' @export 
 dg_closest_res_to_area <- function(dggs,area,round='nearest',show_info=TRUE,metric=TRUE){
   dg_closest_res(dggs,'area_km',area,round,show_info,metric)
@@ -508,11 +502,12 @@ dg_closest_res_to_area <- function(dggs,area,round='nearest',show_info=TRUE,metr
 #' @return A number representing the grid resolution
 #'
 #' @examples 
+#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' res  <- dg_closest_res_to_spacing(dggs,1)
 #' dggs <- dgsetres(dggs,res)
-#'
+#' }
 #' @export 
 dg_closest_res_to_spacing <- function(dggs,spacing,round='nearest',show_info=TRUE,metric=TRUE){
   dg_closest_res(dggs,'spacing_km',spacing,round,show_info,metric)
@@ -543,11 +538,12 @@ dg_closest_res_to_spacing <- function(dggs,spacing,round='nearest',show_info=TRU
 #' @return A number representing the grid resolution
 #'
 #' @examples 
+#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' res  <- dg_closest_res_to_cls(dggs,1)
 #' dggs <- dgsetres(dggs,res)
-#'
+#' }
 #' @export
 dg_closest_res_to_cls <- function(dggs,cls,round='nearest',show_info=TRUE,metric=TRUE){
   dg_closest_res(dggs,'cls_km',cls,round,show_info,metric)
@@ -653,9 +649,10 @@ dg_process_polydata <- function(polydata,frame,wrapcells){
 #'                  Default: NA (do not save grid, return it)
 #'
 #' @return Returns a data frame or OGR poly object, as specified by \code{frame}.
-#'         If \code{savegrid=TRUE}, returns a filename.
+#'         If \code{!is.na(savegrid)}, returns a filename.
 #'
 #' @examples 
+#' \dontrun{
 #' library(dggridR)
 #' dggs <- dgconstruct(spacing=1000,metric=FALSE,resround='down')
 #'
@@ -663,9 +660,9 @@ dg_process_polydata <- function(polydata,frame,wrapcells){
 #' grid <- dgrectgrid(dggs,
 #'                minlat=24.7433195, minlon=-124.7844079, 
 #'                maxlat=49.3457868, maxlon=-66.9513812, frame=TRUE)
-#'
+#' }
 #' @export
-dgrectgrid <- function(dggs,minlat=-1,minlon=-1,maxlat=-1,maxlon=-1,cellsize=0.1,frame=TRUE,wrapcells=TRUE,savegrid=FALSE){ #TODO: Densify?
+dgrectgrid <- function(dggs,minlat=-1,minlon=-1,maxlat=-1,maxlon=-1,cellsize=0.1,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Densify?
   dgverify(dggs) 
 
   coords <- matrix(c(minlon, minlat, maxlon, minlat, maxlon, maxlat, maxlon, minlat, minlon, minlat), ncol = 2, byrow = TRUE)
@@ -673,7 +670,7 @@ dgrectgrid <- function(dggs,minlat=-1,minlon=-1,maxlat=-1,maxlon=-1,cellsize=0.1
   regbox <- SpatialPolygons(list(Polygons(list(regbox), ID = "a")), proj4string=CRS("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs"))
 
   #Generate a dense grid of points
-  samp_points <- sp::makegrid(regbox, cellsize = 0.1)
+  samp_points <- sp::makegrid(regbox, cellsize = cellsize)
 
   #Convert the points to SEQNUM ids for dggs
   samp_points <- dgGEO_to_SEQNUM(dggs,samp_points$x1, samp_points$x2)$seqnum
@@ -709,15 +706,16 @@ dgrectgrid <- function(dggs,minlat=-1,minlon=-1,maxlat=-1,maxlon=-1,cellsize=0.1
 #'                  Default: NA (do not save grid, return it)
 #'
 #' @return Returns a data frame or OGR poly object, as specified by \code{frame}.
-#'         If \code{savegrid=TRUE}, returns a filename.
+#'         If \code{!is.na(savegrid)}, returns a filename.
 #'
 #' @examples 
+#' \dontrun{
 #' library(dggridR)
-#' dggs <- dgconstruct(res=20)
-#' res  <- dg_closest_res_to_spacing(dggs,spacing=1000,round='down',metric=FALSE)
-#' dggs <- dgsetres(dggs,res)
-#' gridfilename <- dgearthgrid(dggs,savegrid=TRUE) #Save directly to a file
-#'
+#' dggs         <- dgconstruct(res=20)
+#' res          <- dg_closest_res_to_spacing(dggs,spacing=1000,round='down',metric=FALSE)
+#' dggs         <- dgsetres(dggs,res)
+#' gridfilename <- dgearthgrid(dggs,savegrid="temp.shp") #Save directly to a file
+#' }
 #' @export
 dgearthgrid <- function(dggs,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Densify?
   dgverify(dggs) 
@@ -761,9 +759,10 @@ dgearthgrid <- function(dggs,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Dens
 #'                  Default: NA (do not save grid, return it)
 #'
 #' @return Returns a data frame or OGR poly object, as specified by \code{frame}.
-#'         If \code{savegrid=TRUE}, returns a filename.
+#'         If \code{!is.na(savegrid)}, returns a filename.
 #'
 #' @examples 
+#' \dontrun{
 #' library(dggridR)
 #' data(dgquakes)
 #'
@@ -773,7 +772,7 @@ dgearthgrid <- function(dggs,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Dens
 #'
 #' #Get grid cells for the earthquakes identified
 #' grid          <- dgcellstogrid(dggs, dgquakes$cell, frame=TRUE)
-#'
+#' }
 #' @export
 dgcellstogrid <- function(dggs,cells,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Densify?
   dgverify(dggs) 
@@ -814,6 +813,7 @@ dgsavegrid <- function(grid,shpfname) {
 }
 
 
+
 #' @name dgshptogrid
 #' 
 #' @title           Return boundary coordinates for cells intersecting a 
@@ -861,14 +861,15 @@ dgsavegrid <- function(grid,shpfname) {
 #'                  Default: NA (do not save grid, return it)
 #'
 #' @return Returns a data frame or OGR poly object, as specified by \code{frame}.
-#'         If \code{savegrid=TRUE}, returns a filename.
+#'         If \code{!is.na(savegrid)}, returns a filename.
 #'
 #' @examples 
+#' \dontrun{
 #' library(dggridR)
 #'
 #' dggs <- dgconstruct(spacing=25, metric=FALSE, resround='nearest')
 #' south_africa_grid <- dgshptogrid(dggs,dg_shpfname_south_africa())
-#'
+#' }
 #' @export
 dgshptogrid <- function(dggs,shpfname,cellsize=0.1,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Densify?
   dgverify(dggs) 
@@ -885,7 +886,7 @@ dgshptogrid <- function(dggs,shpfname,cellsize=0.1,frame=TRUE,wrapcells=TRUE,sav
   poly  <- readOGR(dsn=dsn, layer=layer)
 
   #Generate a dense grid of points
-  samp_points <- sp::makegrid(poly, cellsize = 0.1)
+  samp_points <- sp::makegrid(poly, cellsize = cellsize)
 
   #Convert the points to SEQNUM ids for dggs
   samp_points <- dgGEO_to_SEQNUM(dggs,samp_points$x1, samp_points$x2)$seqnum
